@@ -4,39 +4,7 @@ source("test.prolog.R")
 library(earth)
 data(ozone1)
 data(etitanic)
-
-check.naken <- function(s, expected)
-{
-    nude <- plotmo:::naken.formula.string(s)
-    printf("%-60.60s %-s\n", s, nude)
-    stopifnot(nude == expected)
-}
-printf("=== checking naken.formula.string\n")
-check.naken("y ~ x1 : x2 + x3", "y~x1+x2+x3")
-check.naken("y ~ x1 + x2 - x3", "y~x1+x2+x3")
-check.naken("cbind(damage, 6-damage)~temp", "cbind(damage,6-damage)~temp")
-check.naken("depIndex~q_4+q_2102+q_2104+q_3105+q_3106", "depIndex~q_4+q_2102+q_2104+q_3105+q_3106")
-check.naken("doy ~ (vh+wind+humidity)^2", "doy~vh+wind+humidity")
-check.naken("doy ~ s(wind) + s(humidity,wind) + s(vh)", "doy~wind+humidity+vh")
-check.naken("log(doy) ~ I(vh*wind) + I(humidity*temp)+log(doy)", "log(doy)~vh+wind+humidity+temp+doy")
-check.naken("log(doy)~vh+wind+humidity+I(wind*humidity)+temp+log(ibh)", "log(doy)~vh+wind+humidity+temp+ibh")
-check.naken("O3 ~ s(humidity)+s(temp)+s(ibt)+s(temp,ibt)", "O3~humidity+temp+ibt")
-check.naken("Ozone^(1/3) ~ lo(Solar.R) + lo(Wind, Temp)", "Ozone^(1/3)~Solar.R+Wind+Temp")
-check.naken("Volume~(Girth*Height2)-Height", "Volume~Girth+Height2+Height")
-check.naken("y ~ s(x) + s(x,z1)", "y~x+z1")
-check.naken("y~s(x0,x1,k=12)+s(x2)+s(x3,k=20,fx=20)", "y~x0+x1+x2+x3")
-check.naken("y~x[,1]+x[,2]", "y~x[,1]+x[,2]")
-check.naken("y~x[,1]+x[,my.list$j]", "y~x[,1]+x[,my.list$j]")
-check.naken("y~x[,i]+x[,2]", "y~x[,i]+x[,2]")
-check.naken("Salary~Hitters[,1]", "Salary~Hitters[,1]")
-check.naken("Salary~Hitters[,-1]", "Salary~Hitters[,-1]")
-check.naken("Salary~Hitters[,c(1,2)]", "Salary~Hitters[,c(1,2)]")
-check.naken("Salary~Hitters[,1:2]", "Salary~Hitters[,1:2]")
-check.naken("Salary~Hitters[,c(1,2)]", "Salary~Hitters[,c(1,2)]")
-check.naken("x[,c(1,2)] + x[,3]", "x[,c(1,2)]+x[,3]")
-check.naken("x[,1] + x[,2] + x[,3] + x[,29] + x[,-14]", "x[,1]+x[,2]+x[,3]+x[,29]+x[,-14]")
-check.naken("x[,c(1,2)] + x[,3] + x[,5:6] + x[,-1]", "x[,c(1,2)]+x[,3]+x[,5:6]+x[,-1]")
-check.naken("log(y) ~ x9 + ns(x2,4) + s(x3,x4,df=4) + x5:sqrt(x6)", "log(y)~x9+x2+x3+x4+x5+x6")
+options(warn=1) # print warnings as they occur
 
 # check check.numeric.scalar
 
@@ -74,8 +42,8 @@ expect.err(try(plotmo:::check.integer.scalar(NA)), "argument is NA")
 expect.err(try(plotmo:::check.integer.scalar(NA, null.ok=TRUE)), "argument is NA")
 expect.err(try(plotmo:::check.integer.scalar(NULL)), "argument is NULL")
 expect.err(try(plotmo:::check.integer.scalar(xtest, na.ok=TRUE)), "'xtest' is NULL")
-expect.err(try(plotmo:::check.integer.scalar("xyz", na.ok=TRUE)), "\"xyz\" is a string but it should be an an integer, or NA, or TRUE or FALSE")
-expect.err(try(plotmo:::check.integer.scalar("TRUE", na.ok=TRUE)), "\"TRUE\" is a string but it should be an an integer, or NA, or TRUE or FALSE")
+expect.err(try(plotmo:::check.integer.scalar("xyz", na.ok=TRUE)), "\"xyz\" is a string but it should be an integer, or NA, or TRUE or FALSE")
+expect.err(try(plotmo:::check.integer.scalar("TRUE", na.ok=TRUE)), "\"TRUE\" is a string but it should be an integer, or NA, or TRUE or FALSE")
 stopifnot(identical(plotmo:::check.integer.scalar(TRUE), TRUE))
 stopifnot(identical(plotmo:::check.integer.scalar(NA, na.ok=TRUE), NA))
 x.integer.scalar <- 1234L
@@ -85,7 +53,7 @@ stopifnot(identical(plotmo:::check.integer.scalar(1234, min=2, max=1235), 1234))
 stopifnot(identical(plotmo:::check.integer.scalar(x.integer.scalar, min=2, max=1235), 1234L))
 stopifnot(identical(plotmo:::check.integer.scalar(1234, min=2, max=1235), 1234))
 xtest <- 1.234
-expect.err(try(plotmo:::check.integer.scalar(xtest, min=0, max=3)), "xtest=1.234 but it should be an an integer, or TRUE or FALSE")
+expect.err(try(plotmo:::check.integer.scalar(xtest, min=0, max=3)), "xtest=1.234 but it should be an integer, or TRUE or FALSE")
 
 # check check.vec
 xtest <- "x"
@@ -120,92 +88,100 @@ plotres1 <- function(object, ..., trace=0, SHOWCALL=TRUE, caption=NULL) {
 }
 # basic tests of plotmo on abbreviated titanic data
 
-get.tit <- function()
+get.tita <- function()
 {
-    tit <- etitanic
-    pclass <- as.character(tit$pclass)
+    tita <- etitanic
+    pclass <- as.character(tita$pclass)
     # change the order of the factors so not alphabetical
     pclass[pclass == "1st"] <- "first"
     pclass[pclass == "2nd"] <- "class2"
     pclass[pclass == "3rd"] <- "classthird"
-    tit$pclass <- factor(pclass, levels=c("class2", "classthird", "first"))
+    tita$pclass <- factor(pclass, levels=c("class2", "classthird", "first"))
     # log age is so we have a continuous predictor even when model is age~.
     set.seed(2015)
-    tit$logage <- log(tit$age) + rnorm(nrow(tit))
-    tit$parch <- NULL
+    tita$logage <- log(tita$age) + rnorm(nrow(tita))
+    tita$parch <- NULL
     # by=12 gives us a small fast model with an additive and a interaction term
-    tit <- tit[seq(1, nrow(etitanic), by=12), ]
+    tita[seq(1, nrow(etitanic), by=12), ]
 }
-tit <- get.tit()
+tita <- get.tita()
 
-mod.lm.age <- lm(age~., data=tit)
+mod.lm.age <- lm(age~., data=tita)
 plotmo1(mod.lm.age)
 plotmo1(mod.lm.age, level=.95)
 plotmo1(mod.lm.age, level=.95, col.resp=3)
 
-sexn <- as.numeric(tit$sex)
-mod.lm.sexn <- lm(sexn~.-sex, data=tit)
+sexn <- as.numeric(tita$sex)
+mod.lm.sexn <- lm(sexn~.-sex, data=tita)
 plotmo1(mod.lm.sexn)
 plotmo1(mod.lm.sexn, level=.95)
 
-mod.earth.age <- earth(age~., data=tit, degree=2, nfold=3, ncross=3, varmod.method="lm")
+set.seed(2020)
+mod.earth.age <- earth(age~., data=tita, degree=2, nfold=3, ncross=3, varmod.method="lm")
 plotmo1(mod.earth.age)
 plotmo1(mod.earth.age, level=.9, degree2=0)
 
-# tit[,4] is age
-mod.earth.tit <- earth(tit[,-4], tit[,4], degree=2, nfold=3, ncross=3, varmod.method="lm")
-plotmo1(mod.earth.tit)
-plotmo1(mod.earth.tit, level=.9, degree2=0)
+# tita[,4] is age
+set.seed(2020)
+mod.earth.tita.age <- earth(tita[,-4], tita[,4], degree=2, nfold=3, ncross=3, trace=.5, varmod.method="lm")
+cat("\nsummary(mod.earth.tita.age)\n")
+print(summary(mod.earth.tita.age))
+plotmo1(mod.earth.tita.age)
+plotmo1(mod.earth.tita.age, level=.9, degree2=0)
 
-a.earth.sex <- earth(sex~., data=tit, degree=2, nfold=3, ncross=3, varmod.method="lm")
+set.seed(2020)
+a.earth.sex <- earth(sex~., data=tita, degree=2, nfold=3, ncross=3, varmod.method="lm")
 plotmo1(a.earth.sex)
 plotmo1(a.earth.sex, level=.9)
 plotmo1(a.earth.sex, type="class")
 expect.err(try(plotmo1(a.earth.sex, level=.9, degree2=0, type="class")), "predicted values are strings")
 
-# tit[,3] is sex
-mod.earth.tit <- earth(tit[,-3], tit[,3], degree=2, nfold=3, ncross=3, varmod.method="lm")
-plotmo1(mod.earth.tit)
-plotmo1(mod.earth.tit, level=.9, degree2=0)
-plotmo1(mod.earth.tit, type="class")
-expect.err(try(plotmo1(mod.earth.tit, level=.9, degree2=0, type="class")), "predicted values are strings")
+# tita[,3] is sex
+set.seed(2020)
+mod.earth.tita <- earth(tita[,-3], tita[,3], degree=2, nfold=3, ncross=3, varmod.method="lm")
+plotmo1(mod.earth.tita)
+plotmo1(mod.earth.tita, level=.9, degree2=0)
+plotmo1(mod.earth.tita, type="class")
+expect.err(try(plotmo1(mod.earth.tita, level=.9, degree2=0, type="class")), "predicted values are strings")
 
-mod.earth.sex <- earth(sex~., data=tit, degree=2, nfold=3, ncross=3, varmod.method="earth", glm=list(family=binomial))
+set.seed(2020)
+mod.earth.sex <- earth(sex~., data=tita, degree=2, nfold=3, ncross=3, varmod.method="earth", glm=list(family=binomial))
 plotmo1(mod.earth.sex)
 plotmo1(mod.earth.sex, type="link")
 plotmo1(mod.earth.sex, type="class")
 plotmo1(mod.earth.sex, level=.9, type="earth")
 
-# tit[,3] is sex
-mod.earth.tit <- earth(tit[,-3], tit[,3], degree=2, nfold=3, ncross=3, varmod.method="earth", glm=list(family=binomial))
-plotmo1(mod.earth.tit)
-plotmo1(mod.earth.tit, type="link")
-plotmo1(mod.earth.tit, type="class")
-plotmo1(mod.earth.tit, level=.9, type="earth")
+# tita[,3] is sex
+set.seed(2020)
+mod.earth.tita <- earth(tita[,-3], tita[,3], degree=2, nfold=3, ncross=3, varmod.method="earth", glm=list(family=binomial))
+plotmo1(mod.earth.tita)
+plotmo1(mod.earth.tita, type="link")
+plotmo1(mod.earth.tita, type="class")
+plotmo1(mod.earth.tita, level=.9, type="earth")
 
 # check factor handling when factors are not ordered alphabetically
-tit.orgpclass <- etitanic[seq(1, nrow(etitanic), by=12), ]
-tit  <- get.tit()
-tit$logage <- NULL
-tit.orgpclass$parch <- NULL
-stopifnot(names(tit.orgpclass) == names(tit))
-a.tit.orgpclass <- earth(pclass~., degree=2, data=tit.orgpclass)
-a.tit           <- earth(pclass~., degree=2, data=tit)
-old.warn <- options(warn=2) # treat warnings as errors
-expect.err(try(plotmo(a.tit)), "Defaulting to nresponse=1, see above messages")
-options(warn=old.warn$warn)
+tita.orgpclass <- etitanic[seq(1, nrow(etitanic), by=12), ]
+tita  <- get.tita()
+tita$logage <- NULL
+tita.orgpclass$parch <- NULL
+stopifnot(names(tita.orgpclass) == names(tita))
+a.tita.orgpclass <- earth(pclass~., degree=2, data=tita.orgpclass)
+a.tita           <- earth(pclass~., degree=2, data=tita)
+options(warn=2) # treat warnings as errors
+expect.err(try(plotmo(a.tita)), "Defaulting to nresponse=1, see above messages")
+options(warn=1)
 # following two graphs should be identical
-plotmo1(a.tit.orgpclass, nresponse="1st",   all1=T, col.resp=3, type2="im")
-plotmo1(a.tit,           nresponse="first", all1=T, col.resp=3, type2="im")
+plotmo1(a.tita.orgpclass, nresponse="1st",   all1=T, col.resp=3, type2="im")
+plotmo1(a.tita,           nresponse="first", all1=T, col.resp=3, type2="im")
 # following two graphs should be identical
-plotmo1(a.tit.orgpclass, nresponse="2nd",    all1=T)
-plotmo1(a.tit,           nresponse="class2", all1=T)
+plotmo1(a.tita.orgpclass, nresponse="2nd",    all1=T)
+plotmo1(a.tita,           nresponse="class2", all1=T)
 
-tit  <- get.tit()
-mod.earth.pclass <- earth(pclass~., data=tit, degree=2)
-old.warn <- options(warn=2) # treat warnings as errors
+tita  <- get.tita()
+mod.earth.pclass <- earth(pclass~., data=tita, degree=2)
+options(warn=2) # treat warnings as errors
 expect.err(try(plotmo1(mod.earth.pclass)), "Defaulting to nresponse=1, see above messages")
-options(warn=old.warn$warn)
+options(warn=1)
 plotmo1(mod.earth.pclass, nresponse="fi")
 plotmo1(mod.earth.pclass, nresponse="first")
 plotmo1(mod.earth.pclass, nresponse=3)
@@ -213,28 +189,28 @@ plotmo1(mod.earth.pclass, type="class")
 plotmo1(mod.earth.pclass, nresponse=1,
        type="class", grid.levels=list(sex="fem"),
        smooth.col="indianred", smooth.lwd=2,
-       pt.col=as.numeric(tit$pclass)+1,
+       pt.col=as.numeric(tita$pclass)+1,
        pt.pch=1)
 
-# tit[,1] is pclass
-mod.earth.tit <- earth(tit[,-1], tit[,1], degree=2)
-old.warn <- options(warn=2) # treat warnings as errors
-expect.err(try(plotmo1(mod.earth.tit)), "Defaulting to nresponse=1, see above messages")
-options(warn=old.warn$warn)
-plotmo1(mod.earth.tit, nresponse="first")
-plotmo1(mod.earth.tit, type="class")
+# tita[,1] is pclass
+mod.earth.tita <- earth(tita[,-1], tita[,1], degree=2)
+options(warn=2) # treat warnings as errors
+expect.err(try(plotmo1(mod.earth.tita)), "Defaulting to nresponse=1, see above messages")
+options(warn=1)
+plotmo1(mod.earth.tita, nresponse="first")
+plotmo1(mod.earth.tita, type="class")
 
-mod.earth.pclass2 <- earth(pclass~., data=tit, degree=2, glm=list(family=binomial))
+mod.earth.pclass2 <- earth(pclass~., data=tita, degree=2, glm=list(family=binomial))
 # expect.err(try(plotmo1(mod.earth.pclass2)), "nresponse is not specified")
 plotmo1(mod.earth.pclass2, nresponse=3)
 plotmo1(mod.earth.pclass2, type="link", nresponse=3)
 plotmo1(mod.earth.pclass2, type="class")
 
-# tit[,1] is pclass
-mod.earth.tit <- earth(tit[,-1], tit[,1], degree=2, glm=list(family=binomial))
-plotmo1(mod.earth.tit, nresponse=3)
-plotmo1(mod.earth.tit, type="link", nresponse=3)
-plotmo1(mod.earth.tit, type="class")
+# tita[,1] is pclass
+mod.earth.tita <- earth(tita[,-1], tita[,1], degree=2, glm=list(family=binomial))
+plotmo1(mod.earth.tita, nresponse=3)
+plotmo1(mod.earth.tita, type="link", nresponse=3)
+plotmo1(mod.earth.tita, type="class")
 
 # plotmo vignette examples
 
@@ -264,7 +240,7 @@ printf("library(rpart)\n")
 library(rpart)                                          # rpart
 rpart.model.vignette <- rpart(O3 ~ ., data=oz)
 plotmo1(rpart.model.vignette, all2=TRUE)
-expect.err(try(plotmo1(rpart.model.vignette, level=.9)), "not supported for rpart objects")
+expect.err(try(plotmo1(rpart.model.vignette, level=.9)), "the level argument is not supported for \"rpart\" objects")
 
 # commented out because is slow and already tested in test.non.earth.R
 # printf("library(randomForest)\n")
@@ -307,17 +283,17 @@ plotmo1(qda.model.vignette, type="class", all2=TRUE,
 
 # miscellaneous other examples
 
-tit <- get.tit()
+tita <- get.tita()
 
-mod.glm.sex <- glm(sex~., data=tit, family=binomial)
-plotmo1(mod.glm.sex, pt.col=as.numeric(tit$pclass)+1)
+mod.glm.sex <- glm(sex~., data=tita, family=binomial)
+plotmo1(mod.glm.sex, pt.col=as.numeric(tita$pclass)+1)
 
-# tit[,4] is age, tit[,1] is pclass
+# tita[,4] is age, tita[,1] is pclass
 printf("library(lars)\n")
 library(lars)
 set.seed(2015)
-xmat <- as.matrix(tit[,c(2,5,6)])
-mod.lars.xmat <- lars(xmat, tit[,4])
+xmat <- as.matrix(tita[,c(2,5,6)])
+mod.lars.xmat <- lars(xmat, tita[,4])
 par(mfrow=c(2,2))
 plot(mod.lars.xmat)
 plotmo1(mod.lars.xmat, nresponse=4, do.par=F)
@@ -327,7 +303,7 @@ if(0) { # TODO fails with R-3.4.2: object '.QP_qpgen2' not found
     printf("library(cosso)\n")
     library(cosso)
     set.seed(2016)
-    cosso <- cosso(xmat,tit[,4],family="Gaussian")
+    cosso <- cosso(xmat,tita[,4],family="Gaussian")
     # TODO tell maintainer of cosso that you have to do this
     class(cosso) <- "cosso"
     set.seed(2016)
@@ -401,20 +377,22 @@ plotmo(a)
 # test "the variable on the right side of the formula is a matrix or data.frame"
 # TODO would like to solve this problem
 
-old.warn <- options("warn")
 options(warn=2)
-
 data(gasoline, package="pls")
 earth.octane <- earth(octane ~ NIR, data=gasoline)
+print(summary(earth.octane)) # ok
+plotres(earth.octane) # ok
 expect.err(try(plotmo(earth.octane)), "the variable on the right side of the formula is a matrix or data.frame")
+options(warn=1)
 
-library(ElemStatLearn)
-x <- mixture.example$x
-g <- mixture.example$y
-lm.mixture.example <- lm(g ~ x)
-expect.err(try(plotmo(lm.mixture.example)), "the variable on the right side of the formula is a matrix or data.frame")
-
-options(warn=old.warn$warn)
+# TODO May 2020 'ElemStatLearn' is not available (for R version 4.0.0)
+# library(ElemStatLearn)
+# x <- mixture.example$x
+# g <- mixture.example$y
+# lm.mixture.example <- lm(g ~ x)
+# options(warn=2)
+# expect.err(try(plotmo(lm.mixture.example)), "the variable on the right side of the formula is a matrix or data.frame")
+# options(warn=1)
 
 # test variable names with $ are not supported
 
@@ -432,7 +410,6 @@ expect.err(try(plotmo(a)), "cannot get the original model predictors")
 
 #--- test interaction of w1. and non w1 args -------------------------------------
 
-old.par <- par(no.readonly=TRUE)
 par(mfrow=c(4,3), mar=c(3, 3, 4, 1), mgp=c(2, 0.6, 0))
 
 mod78 <- earth(Volume ~ ., data = trees)
@@ -448,9 +425,8 @@ plotres(mod78, cex.main=.7,
         w1.ylim=c(-.5, .8), w1.xlim=c(-2, 7), col=2:3, do.par=FALSE,
         ylim=c(-10,10), xlim=c(-30, 100),
         w1.main=c("w1.ylim=c(-.5, .8) w1.xlim=c(-2, 7)\nylim=c(-10,10), xlim=c(-30, 100)"))
+par(org.par)
 
-par(old.par)
-old.par <- par(no.readonly=TRUE)
 par(mfrow=c(3,4), mar=c(3, 3, 3, 1), mgp=c(2, 0.6, 0))
 
 # which=1, earth model
@@ -490,6 +466,14 @@ plotres(mod78, which=3, cex.main=1,
         col=2:3, w1.ylim=c(.3,.98), ylim=c(-10,10), w1.xlim=c(-2, 7), xlim=c(-90,90),
         main="w1.ylim=c(.3,.98) ylim=c(-10,10)\nw1.xlim=c(-2, 7), xlim=c(-90,90)")
 
-par(old.par)
+par(org.par)
+
+nullarg <- NULL
+expect.err(try(plotmo(nullarg)),   "argument 'nullarg' is NULL")
+expect.err(try(plotmo(NULL)),      "argument 'NULL' is NULL")
+expect.err(try(plotmo(0)),         "'0' is not an S3 model")
+expect.err(try(plotmo(list(1,2))), "'list(1, 2)' is a plain list, not an S3 model")
+expect.err(try(plotmo(list(1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0,1,2,3,4,5,6,7,8,0))),
+               "object is a plain list, not an S3 model")
 
 source("test.epilog.R")
